﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="OptionsPage.cs" company="Mar3ek">
//   http://mar3ek.wordpress.com
// </copyright>
// <summary>
//   Defines the OptionsPage type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Mar3ek.ColorHatTimeTracker
{
    using System;
    using System.ComponentModel;
    using System.Runtime.InteropServices;

    using Microsoft.VisualStudio.Shell;

    /// <summary>
    /// The options page.
    /// </summary>
    [ClassInterface(ClassInterfaceType.AutoDual)]
    [CLSCompliant(false), ComVisible(true)]
    public class OptionsPage : DialogPage
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="OptionsPage"/> class.
        /// </summary>
        public OptionsPage()
        {
            this.Username = string.Empty;
            this.Password = string.Empty;
        }

        /// <summary>
        /// Gets or sets the username.
        /// </summary>
        [Category("Colorhat"), DisplayName("Username"), Description("The login name used to access your Colorhat account.")]
        public string Username { get; set; }

        /// <summary>
        /// Gets or sets the password.
        /// </summary>
        [Category("Colorhat"), DisplayName("Password"), Description("The password used to access your Colorhat account."), PasswordPropertyText(true)]
        public string Password { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether to suppress annotation window.
        /// </summary>
        [Category("Colorhat"), DisplayName("Suppress annotation window"), Description("Indicates whether to suppress the time segment annotation window after time tracking has been stopped.")]
        public bool SuppressAnnotation { get; set; }
    }
}
